"""
See:
https://github.com/amirasaran/pars-green
"""

# Always prefer setuptools over distutils
from setuptools import setup
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='pars-green',
    version='1.0.1',
    description='Python Pars Green',
    long_description=long_description,
    url='https://github.com/mhipo1364/pars-green',
    author='Mohammad Torkianfar',
    author_email='mhipo1364@gmail.com',
    license='MIT',
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
    ],
    packages=['pars_green'],
    # What does your project relate to?
    keywords='pars green soap',
    install_requires=['suds>=0.4'],
)



from suds.client import Client


class ParsGreenSmsServiceClient(object):
    sendSmsURL = 'http://login.parsgreen.com/Api/SendSMS.asmx?WSDL'
    profileServiceURL = 'http://login.parsgreen.com/Api/profileservice.asmx?WSDL'
    msgServiceURL = 'http://login.parsgreen.com/Api/MsgService.asmx?WSDL'
    scheduleServiceURL = 'http://login.parsgreen.com/Api/ScheduleService.asmx?WSDL'

    def __init__(self, signature):
        self.sms_client = Client(self.sendSmsURL)
        self.profile_client = Client(self.profileServiceURL)
        # on creating msg service client program crash
        self.scheduleClient = Client(self.scheduleServiceURL)

        self.signature = signature
        self.udh = ""
        self.success = 0x0
        self.retStr = []

    def get_send_sms_client(self):
        return self.sms_client

    def get_profile_client(self):
        return self.profile_client

    # Sending text messages method
    def send(self, from_number, to, text, is_flash=False):
        str_arr = self.sms_client.factory.create('ArrayOfString')
        str_arr.string = to
        self.retStr = self.sms_client.service.SendGroupSMS(
            self.signature,
            from_number,
            str_arr,
            text,
            is_flash,
            self.udh,
            self.success,
            self.retStr
        )
        return self.retStr

    # Get delivery method
    def get_delivery(self, rec_id):
        """

        :param rec_id:
        :return:
        """
        return self.sms_client.service.GetDelivery(self.signature, rec_id)

    # Get number of received text messages
    def get_message_count(self, location, is_read):
        """

        :param location:
        :param is_read:
        :return:
        """
        return self.sms_client.service.GetMsgCount(self.signature, location, is_read)

    # Delete either received or sent text messages
    def delete_message(self, encrypted_message_id):
        """

        :param encrypted_message_id:
        :return:
        """
        return self.sms_client.service.MsgDelete(self.signature, encrypted_message_id)

    # Change text message as unread/read
    def get_message_change_is_read(self, location, is_read):
        """

        :param location:
        :param is_read:
        :return:
        """
        return self.sms_client.service.MsgChangeIsRead(self.signature, location, is_read)

    # Get either received or sent text messages
    def get_message(self, location, is_read):
        """

        :param location:
        :param is_read:
        :return:
        """
        return self.sms_client.service.GetMessage(self.signature, location, is_read)

    # Get credit amount left in your account
    def get_credit(self):
        """

        :return:
        """
        return self.profile_client.service.GetCredit(self.signature)

    # For transfer credit between from one account to another
    def transfer_credit(self, to_username, to_password, amount):
        """

        :param to_username:
        :param to_password:
        :param amount:
        :return:
        """
        return self.profile_client.service.TransferCredit(self.signature, to_username, to_password, amount)

    def register_schedule_daily(self, hour, minute, text, to, from_number, encrypted_schedule_id):
        """

        :param hour:
        :param minute:
        :param text:
        :param to:
        :param from_number:
        :param encrypted_schedule_id:
        :return:
        """
        str_arr = self.scheduleClient.factory.create('ArrayOfString')
        str_arr.string = to
        return self.scheduleClient.service.RegSchdeuleDaily(self.signature, hour, minute, text, str_arr, from_number,
                                                            encrypted_schedule_id)

    def register_schedule_yearly(self, month_of_year, day_of_month, hour, minute, text, to, from_number, encrypted_schedule_id):
        """

        :param month_of_year: In Jalali Calendar
        :param day_of_month: In Jalali Calendar
        :param hour:
        :param minute:
        :param text:
        :param to:
        :param from_number:
        :param encrypted_schedule_id:
        :return:
        """
        str_arr = self.scheduleClient.factory.create('ArrayOfString')
        str_arr.string = to
        return self.scheduleClient.service.RegSchdeuleYearly(self.signature, month_of_year, day_of_month, hour, minute,
                                                             text, str_arr, from_number, encrypted_schedule_id)

    def delete_schedule(self, encrypted_schedule_id):
        return self.scheduleClient.service.DeleteSchedule(self.signature, encrypted_schedule_id)
